.. py:currentmodule:: rubin_sim

.. _selfcal:

################
Self Calibration
################

The ``rubin_sim.selfcal`` module contains tools for simulating a basic
self-calibration effort. This was used to estimate photometric errors
remaining after self-calibration in `LSE-180 <https://ls.st/lse-180>`_.
This module remains useful for first-pass investigations into the effects
of survey strategy choices on the resulting photometric calibration
possibilities, which in particular can be useful for investigating
the effects of footprint or rolling cadence.